#
# spec file for package dyff
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dyff
Version:        1.9.4
Release:        1.1
Summary:        Diff tool for YAML files, and sometimes JSON
License:        MIT
URL:            https://github.com/homeport/dyff
Source:         dyff-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.23

%description
A diff tool for YAML files, and sometimes JSON.

dyff is inspired by the way the old BOSH v1 deployment output reported changes
from one version to another by only showing the parts of a YAML file that
change.

Each difference is referenced by its location in the YAML document by using
either the Spruce dot-style syntax (some.path.in.the.file) or go-patch path
syntax (/some/name=path/in/the/id=file). The output report aims to be as
compact as possible to give a clear and simple overview of the change.

Similar to the standard diff tool, it follows the principle of describing the
change by going from the from input file to the target to input file.

Input files can be local files (filesystem path), remote files (URI), or the
standard input stream (using -).

All orders of keys in hashes are preserved during processing and output to the
terminal, most notably in the sub-commands to convert YAML to JSON and vice
versa.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/homeport/dyff/internal/cmd.version=%{version}" \
   -o bin/dyff ./cmd/dyff

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Thu Dec  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.4 (1.9.2 and 1.9.3 were on the same commit
  as 1.9.1):
  * Bump codecov/codecov-action from 4 to 5
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.1:
  * Bump golang.org/x/tools from 0.24.0 to 0.25.0
  * Bump golang.org/x/net from 0.28.0 to 0.29.0
  * Bump golang.org/x/term from 0.23.0 to 0.24.0
  * Bump golang.org/x/text from 0.17.0 to 0.18.0
  * Bump golang.org/x/sys from 0.24.0 to 0.25.0
  * Bump Go version to `1.23`
  * Bump github.com/onsi/ginkgo/v2 from 2.20.0 to 2.20.1
  * Bump golang.org/x/sys from 0.23.0 to 0.24.0
  * Bump golang.org/x/tools from 0.23.0 to 0.24.0
  * Bump github.com/onsi/ginkgo/v2 from 2.19.1 to 2.20.0
  * Bump golang.org/x/net from 0.27.0 to 0.28.0
  * Bump golang.org/x/term from 0.22.0 to 0.23.0
  * Bump golang.org/x/sys from 0.22.0 to 0.23.0
  * Bump golang.org/x/sync from 0.7.0 to 0.8.0
  * Unify `.goreleaser.yml` configuration
* Sat Aug  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.0:
  * Fix unquoted string in download script
  * Make `download-latest.sh` configurable
  * Introduce `--ignore-whitespace-changes` flag
  * Bump github.com/onsi/gomega from 1.34.0 to 1.34.1
  * Bump github.com/mattn/go-isatty from 0.0.19 to 0.0.20
  * Bump github.com/BurntSushi/toml from 1.3.2 to 1.4.0
  * Update `dependabot.yml` config
  * Bump github.com/onsi/ginkgo/v2 from 2.19.0 to 2.19.1
  * Update download-latest.sh to support multiple download URLs
* Wed Jul 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.1:
  * Bump `golang.org/x` dependencies
  * Bump dependabot/fetch-metadata from 2.1.0 to 2.2.0
  * Bump github.com/spf13/cobra from 1.8.0 to 1.8.1
  * Bump goreleaser/goreleaser-action from 5 to 6
  * Refactor single entry check
  * Fix `gocritic` findings main entry
  * Use Go `1.22` for builds/releases
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.0:
  * Refactor message to fix misspell finding
  * Fix `BeLike` expected error type
  * Bump golangci/golangci-lint-action from 5 to 6
  * Support different syntax highlighters
  * Add markdown report output
  * Bump github.com/onsi/ginkgo/v2 from 2.18.0 to 2.19.0
  * updated-dependencies:
  - dependency-name: github.com/onsi/ginkgo/v2
    dependency-type: direct:production
    update-type: version-update:semver-minor ...
  * Use `directory` instead of `folder` in GoReleaser
  * Bump github.com/onsi/ginkgo/v2 from 2.17.2 to 2.17.3
  * Bump github.com/onsi/gomega from 1.33.0 to 1.33.1
  * Bump dependabot/fetch-metadata from 1.6.0 to 2.1.0
  * Bump golangci/golangci-lint-action from 4 to 5
  * Bump github.com/onsi/ginkgo/v2 from 2.17.1 to 2.17.2
  * Bump github.com/onsi/gomega from 1.32.0 to 1.33.0
  * This doesn't work since golang 1.20
  * Bump github.com/onsi/ginkgo/v2 from 2.15.0 to 2.17.1
  * Bump github.com/onsi/gomega from 1.31.1 to 1.32.0
  * Bump codecov/codecov-action from 3 to 4
  * Bump actions/checkout from 3 to 4
  * Bump actions/setup-go from 3 to 5
  * Bump dependabot/fetch-metadata from 1.3.5 to 1.6.0
  * Bump goreleaser/goreleaser-action from 2 to 5
  * Bump golangci/golangci-lint-action from 3 to 4
  * Add `github-actions` to Dependabot
* Sat May 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- do not strip aka remove -s -w ldflags
* Sun Feb 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.1:
  * Fix dash quotation issue
  * Replace deprecated changelog setting name
  * Use `repository` instead of `tap`
* Tue Feb  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.0:
  * Use Ginkgo version from modules
  * fix incorrect newline handling
  * adapt testcases
  * fix diff issue with latest version of go-diff lib
  * improve multiline string diff handling
  * Bump github.com/onsi/gomega from 1.31.0 to 1.31.1
  * Bump github.com/onsi/ginkgo/v2 from 2.14.0 to 2.15.0
  * Bump github.com/onsi/gomega from 1.30.0 to 1.31.0
  * Handle comparisons of boolean values correctly
  * Bump github.com/onsi/ginkgo/v2 from 2.13.2 to 2.14.0
  * Bump github.com/onsi/ginkgo/v2 from 2.13.1 to 2.13.2
  * Bump github.com/onsi/ginkgo/v2 from 2.13.0 to 2.13.1
  * Bump github.com/onsi/gomega from 1.29.0 to 1.30.0
  * Bump github.com/spf13/cobra from 1.7.0 to 1.8.0
  * Bump github.com/onsi/gomega from 1.28.1 to 1.29.0
  * Bump github.com/onsi/gomega from 1.28.0 to 1.28.1
  * Remove usage of deprecated `wrap.Error` function
* Thu Oct 19 2023 kastl@b1-systems.de
- Update to version 1.6.0:
  * Add test case where from or to is null
  * Add test case to check new if branch
  * Introduce identifier interface
  * Provide Kubernetes lists example
  * Refactor core code by sorting functions
  * Refactor core code
  * Use `assets` function in test cases
  * Add `apiVersion` to Kubernetes look-up
  * Move Kubernetes assests into subdirectories
  * Bump golang.org/x/net from 0.16.0 to 0.17.0
  * Bump github.com/onsi/ginkgo/v2 from 2.12.1 to 2.13.0
  * Tidy up test setup
  * Bump github.com/onsi/gomega from 1.27.10 to 1.28.0
  * Bump github.com/onsi/ginkgo/v2 from 2.12.0 to 2.12.1
  * Update Go version in README
  * Bump Go version to `1.20`
  * Bump github.com/onsi/ginkgo/v2 from 2.11.0 to 2.12.0
  * Bump github.com/onsi/gomega from 1.27.8 to 1.27.10
* Fri Jun 30 2023 kastl@b1-systems.de
- Update to version 1.5.8:
  * Bump to neat release `v1.3.12`
  * Bump github.com/onsi/ginkgo/v2 from 2.10.0 to 2.11.0
  * Bump github.com/onsi/ginkgo/v2 from 2.9.7 to 2.10.0
  * Bump github.com/onsi/gomega from 1.27.7 to 1.27.8
  * Bump github.com/onsi/ginkgo/v2 from 2.9.5 to 2.9.7
  * Bump github.com/onsi/gomega from 1.27.6 to 1.27.7
  * Bump github.com/onsi/ginkgo/v2 from 2.9.4 to 2.9.5
  * Bump github.com/onsi/ginkgo/v2 from 2.9.3 to 2.9.4
  * Bump github.com/onsi/ginkgo/v2 from 2.9.2 to 2.9.3
* Tue May 30 2023 Andreas Schwab <schwab@suse.de>
- Don't try to link statically
* Mon Apr 17 2023 kastl@b1-systems.de
- Update to version 1.5.7:
  * Remove `snap` target for now
  * Switch to `SNAPCRAFT_STORE_CREDENTIALS` environment variable
  * Enable Windows builds (again)
  * Introduce auto-merge idea for dependabot
  * Tweak Ginkgo install
  * Update README with Go version
  * Tweak unit test setup for CI
  * Switch to ad-hoc Ginkgo
* Tue Mar 28 2023 Johannes Kastl <kastl@b1-systems.de>
- new package dyff: diff tool for YAML files, and sometimes JSON
